#include <check.h>
#include <errno.h>
#include <stdio.h>
#include <unistd.h>

#include "ttail_check.h"
#include "ttail.h"
#include "ttail_init.h"

/*
 * ttail_set_prefix() tests
 */
START_TEST (test_init_prefix)
{
	int ret;
	ret = ttail_set_prefix(ttail, "^[^ ]+ ");
	ck_assert_int_eq(ret, 0);
	ck_assert((ttail->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
}
END_TEST

START_TEST (test_init_bad_prefix)
{
	int ret;
	ret = ttail_set_prefix(ttail, "^[^ + ");
	ck_assert_int_eq(ret, -1);
	ck_assert((ttail->flag & TTAIL_FLAG_PREFIX) == 0);
}
END_TEST

START_TEST (test_init_again_prefix)
{
	int ret;
	ret = ttail_set_prefix(ttail, "^[^ ]+ ");
	ck_assert_int_eq(ret, 0);
	ck_assert((ttail->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
	ret = ttail_set_prefix(ttail, "^[^ + ");
	ck_assert_int_eq(ret, 1);
	ck_assert((ttail->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
}
END_TEST

START_TEST (test_init_againbad_prefix)
{
	int ret;
	ret = ttail_set_prefix(ttail, "^[^ + ");
	ck_assert_int_eq(ret, -1);
	ck_assert((ttail->flag & TTAIL_FLAG_PREFIX) == 0);

	ret = ttail_set_prefix(ttail, "^[^ ]+ ");
	ck_assert_int_eq(ret, 0);
	ck_assert((ttail->flag & TTAIL_FLAG_PREFIX) == TTAIL_FLAG_PREFIX);
}
END_TEST

Suite * ttail_init_suite(void)
{
	Suite *s;
	TCase	*tc_init_prefix;

	s = suite_create("ttail init checks");

	tc_init_prefix = tcase_create("date prefix regex init checks");
	tcase_add_checked_fixture(tc_init_prefix,
		setup_ttail_empty, teardown_ttail);
	tcase_add_test(tc_init_prefix, test_init_prefix);
	tcase_add_test(tc_init_prefix, test_init_bad_prefix);
	tcase_add_test(tc_init_prefix, test_init_again_prefix);
	tcase_add_test(tc_init_prefix, test_init_againbad_prefix);

	suite_add_tcase(s, tc_init_prefix);
	return s;
}

TTAIL_CHECK_MAIN(ttail_init_suite)
