#include <check.h>
#include <stdio.h>
#include <libgen.h>

#include "ttail_check.h"
#include "ttail.h"
#include "ttail_init.h"
#include "ttail_search.h"

/*
 * ttail_logline2date() checks
 */
START_TEST (test_search_log2date1)
{
	char re[] = "^[0-9]+ ";
	char fmt[] = "%Y-%m-%d:%H:%M";
	struct tm tm;
	int ret;
	ttail_set_flag_re_ex(ttail);
	ttail_set_prefix(ttail, re);
	ttail_set_fmt(ttail, fmt);
	ret = ttail_logline2date(ttail, "1337 1988-10-22:22:10 foobar", &tm);
	ck_assert_int_eq(ret, 0);
	ck_assert_int_eq(tm.tm_year, 88);
	ck_assert_int_eq(tm.tm_mon, 9);
	ck_assert_int_eq(tm.tm_mday, 22);
	ck_assert_int_eq(tm.tm_hour, 22);
	ck_assert_int_eq(tm.tm_min, 10);
}
END_TEST

START_TEST (test_search_log2date_failpref)
{
	char re[] = "^[0-9]+aa ";
	char fmt[] = "%Y-%m-%d:%H:%M";
	struct tm tm;
	int ret;
	ttail_set_flag_re_ex(ttail);
	ttail_set_prefix(ttail, re);
	ttail_set_fmt(ttail, fmt);
	ret = ttail_logline2date(ttail, "1337 1988-10-22:22:10 foobar", &tm);
	ck_assert_int_eq(ret, 1);
	ck_assert_int_eq(tm.tm_year, 0);
	ck_assert_int_eq(tm.tm_mon, 0);
	ck_assert_int_eq(tm.tm_mday, 0);
	ck_assert_int_eq(tm.tm_hour, 0);
	ck_assert_int_eq(tm.tm_min, 0);
}
END_TEST

START_TEST (test_search_log2date_faildate)
{
	char re[] = "^[0-9]+ ";
	char fmt[] = "%y-%m-%d:%H:%M";
	struct tm tm;
	int ret;
	ttail_set_flag_re_ex(ttail);
	ttail_set_prefix(ttail, re);
	ttail_set_fmt(ttail, fmt);
	ret = ttail_logline2date(ttail, "1337 1988-10-22:22:10 foobar", &tm);
	ck_assert_int_eq(ret, 2);
	ck_assert_int_eq(tm.tm_year, 0);
	ck_assert_int_eq(tm.tm_mon, 0);
	ck_assert_int_eq(tm.tm_mday, 0);
	ck_assert_int_eq(tm.tm_hour, 0);
	ck_assert_int_eq(tm.tm_min, 0);
}
END_TEST

Suite * ttail_search_files_suite(void)
{
	Suite *s;
	TCase *tc_search_logline2date;

	s = suite_create("ttail search_files checks");

	tc_search_logline2date = tcase_create("ttail_logline2date() checks");
	tcase_add_checked_fixture(tc_search_logline2date,
		setup_closest_fileinit, teardown_closest_fileinit);
	tcase_add_test(tc_search_logline2date, test_search_log2date1);
	tcase_add_test(tc_search_logline2date, test_search_log2date_failpref);
	tcase_add_test(tc_search_logline2date, test_search_log2date_faildate);

	suite_add_tcase(s, tc_search_logline2date);
	return s;
}

TTAIL_CHECK_MAIN(ttail_search_files_suite)
